@@ -66,13 +66,15 @@ DESCRIPTION="This package provides add-on qml files for the Kirigami framework."
 
 EXT_VERSION=$(basename $PKG_KIRIGAMI_ADDONS .tar.xz | cut -d "-" -f 3) 
 
+LC_ALL=C.UTF8
+
 mkdir build &&
 cd    build &&
 
 cmake -D CMAKE_INSTALL_PREFIX=$KF6_PREFIX \
       -D CMAKE_BUILD_TYPE=Release         \
       -D BUILD_TESTING=OFF                \
-       ..                                 &&
+       ..
 make
 
 # As root:
